@@ -1,4 +1,5 @@
 import logging
+import six.moves
 import itertools
 from collections import namedtuple
 from six import string_types
@@ -17,7 +18,8 @@ class Table(object):
 
     """The basic table class. Table objects contain
     any Python data type, however some features may be unavailable
-    if the types are non-hashable."""
+    if the types are non-hashable.
+    """
 
     def __init__(self, schema, data=[]):
         """
@@ -38,6 +40,7 @@ class Table(object):
         :type schema: list
         :param data: Optional rows of data to initialize the table.
         :type data: list of lists
+
         """
         self._columns = []
         self.indexes = WeakValueDictionary()
@@ -67,7 +70,7 @@ class Table(object):
             raise InvalidData(
                 "Expected %d columns, got %d" % (len(row), len(self._columns))
             )
-        zipped = zip(row, self._columns)
+        zipped = list(six.moves.zip(row, self._columns))
         for v, c in zipped:
             if not isinstance(v, c.type):
                 if not v is None:  # Nonetypes are always valid
@@ -133,7 +136,7 @@ class Table(object):
         Each row behaves like a namedtuple.
         """
         s = self._tablerow_schema()
-        for r in itertools.izip(*self._columns):
+        for r in six.moves.zip(*self._columns):
             yield TableRow(r, s)
 
     def _tablerow_schema(self):
@@ -202,7 +205,7 @@ class Table(object):
         """Internal function: This specifies the order in which the
         __iter__ method retreives rows.
         """
-        return xrange(len(self))
+        return six.moves.range(len(self))
 
     def rename(self, old_names, new_names):
         """Rename columns in the table. Does not affect the order of
@@ -255,6 +258,7 @@ class Table(object):
         :type input_columns: list of str
         :param fn; A function or lambda
         :param type: Optionally, constrain the value of this column by type
+
         """
         incols = []
         for c in input_columns:
@@ -393,7 +397,7 @@ class Table(object):
         if self.schema != ano.schema:
             return False
 
-        for a, b in itertools.izip_longest(self, ano):
+        for a, b in six.moves.zip_longest(self, ano):
             if a != b:
                 return False
 
@@ -491,7 +495,7 @@ class AggregationTable(Table):
         self.aggregations = [Aggregation(*a) for a in aggregations]
 
     def _indices_func(self):
-        return xrange(len(self.i.unique_values()))
+        return six.moves.range(len(self.i.unique_values()))
 
     def _iter_subtables(self):
         """Generator function that gives a sequnce of (values, table) which represents
@@ -516,11 +520,11 @@ class AggregationTable(Table):
         )
 
     def get_row(self, row):
-        row_keys, subtable = itertools.islice(
+        row_keys, subtable = next(itertools.islice(
             self._iter_subtables(),
             row,
             row + 1
-        ).next()
+        ))
         r = row_keys + tuple(a(subtable) for a in self.aggregations)
         return TableRow(r, self.column_names)
 
@@ -532,7 +536,7 @@ class AggregationTable(Table):
 
     @property
     def schema(self):
-        return zip(self.column_names, self.column_types)
+        return list(zip(self.column_names, self.column_types))
 
     def __getattr__(self, key):
         return ('Pikachu', 'Normal', 4)
@@ -687,8 +691,8 @@ class JoinTable(DerivedTable):
         jcs = self._join_columns
 
         try:
-            i, ji = itertools.islice(
-                self._both_indices_func(), key, key + 1).next()
+            i, ji = next(itertools.islice(
+                self._both_indices_func(), key, key + 1))
         except StopIteration:
             raise IndexError(key)
 
